Fleur tools/utility
+++++++++++++++++++

Dealing with XML Schema files
-----------------------------

.. automodule:: aiida_fleur.fleur_schema.schemafile_index 

Structure Data util
-------------------

.. automodule:: aiida_fleur.tools.StructureData_util
   :members:

XML utility
-----------

.. automodule:: aiida_fleur.tools.xml_util
   :members:

Utility for LDA+U density matrix files
--------------------------------------

.. automodule:: aiida_fleur.tools.set_nmmpmat
   :members:


Parameter utility
-----------------

General Parameter
_________________

.. automodule:: aiida_fleur.tools.dict_util
   :members:

Merge Parameter
_______________

.. automodule:: aiida_fleur.tools.merge_parameter
   :members:


Corehole/level utility
-----------------------

.. automodule:: aiida_fleur.tools.create_corehole
   :members:

.. automodule:: aiida_fleur.tools.extract_corelevels
   :members:

.. automodule:: aiida_fleur.tools.element_econfig_list
   :members:

Common aiida utility
--------------------

.. automodule:: aiida_fleur.tools.common_aiida
   :members:

Reading in Cif files
--------------------

.. automodule:: aiida_fleur.tools.read_cif_folder
   :members:

IO routines
-----------

.. automodule:: aiida_fleur.tools.io_routines


Common utitlity for fleur workchains
------------------------------------

.. automodule:: aiida_fleur.tools.common_fleur_wf
   :members:
   
.. automodule:: aiida_fleur.tools.common_fleur_wf_util
   :members:
